@@ -9,7 +9,6 @@ Example usage:
 import argparse
 import fnmatch
 import logging
-import multiprocessing
 import platform
 import sys
 from pathlib import Path
@@ -129,31 +128,26 @@ def run(raw_args=None):
         format="%(asctime)s %(levelname)-8s %(message)s",
     )
 
-    if platform.system() == "Darwin":
-        multiprocessing.set_start_method("spawn")
+    with timed("All"):
+        with timed("Find"):
+            matches, include = find(args)
 
-    with multiprocessing.Pool() as pool:
-        with timed("All"):
-            with timed("Find"):
-                result = pool.map(find, [args])
-                matches, include = result[0]
+        with timed("Filter"):
+            matches = filter_include(matches, [include])
+            matches = filter_exclude(matches, args.exclude)
 
-            with timed("Filter"):
-                matches = filter_include(matches, [include])
-                matches = filter_exclude(matches, args.exclude)
+        with timed("Load"):
+            libs = [try_load(match) for match in matches]
+            libs = [lib for lib in libs if lib is not None]
 
-            with timed("Load"):
-                libraries = pool.map(try_load, matches)
-                libraries = [lib for lib in libraries if lib is not None]
+        if not args.no_patches:
+            with timed("Patch"):
+                for lib in libs:
+                    patcher.apply_all(lib)
 
-            if not args.no_patches:
-                with timed("Patch"):
-                    for lib in libraries:
-                        patcher.apply_all(lib)
+        args.output.mkdir(parents=True, exist_ok=True)
+        with timed("Convert"):
+            for lib in libs:
+                converter.convert(lib, args.format, args.output)
 
-            args.output.mkdir(parents=True, exist_ok=True)
-            with timed("Convert"):
-                for lib in libraries:
-                    converter.convert(lib, args.format, args.output)
-
-        logging.info("Created %d file(s)", len(libraries))
+    logging.info("Created %d file(s)", len(libs))
